@@ -15,12 +15,12 @@ use Types::Path::Tiny qw( Dir File Path );
 use Path::Tiny;
 use Try::Tiny;
 use Template::Tiny;
-use File::ShareDir::ProjectDistDir;
+use File::ShareDir;
 
 use Role::Commons -all;
 
 our $AUTHORITY = 'cpan:JONASS';
-our $VERSION = 'v1.1.1';
+our $VERSION = 'v1.1.2';
 
 # permit callers to sloppily pass undefined hash values
 sub BUILDARGS
